@@ -1,3 +1,4 @@
+import json
 from typing import Any, Dict, List, Union
 
 from pyspark.ml.base import Transformer
@@ -14,6 +15,7 @@ from spark_pipeline_framework.transformers.framework_transformer.v1.framework_tr
 from spark_pipeline_framework.utilities.FriendlySparkException import (
     FriendlySparkException,
 )
+from spark_pipeline_framework.utilities.class_helpers import ClassHelpers
 from spark_pipeline_framework.utilities.pipeline_helper import create_steps
 
 
@@ -123,3 +125,21 @@ class FrameworkPipeline(Transformer):
 
     def finalize(self) -> None:
         pass
+
+    def as_dict(self) -> Dict[str, Any]:
+        return {
+            "short_type": self.__class__.__name__,
+            "type": ClassHelpers.get_full_name_of_instance(self),
+            # self.parameters is a subclass of dict so json.dumps thinks it can't serialize it
+            "params": {
+                k: v if not hasattr(v, "as_dict") else v.as_dict()
+                for k, v in self.parameters.items()
+            },
+            "steps": [
+                s.as_dict() if not isinstance(s, list) else [s1.as_dict() for s1 in s]
+                for s in self.steps
+            ],
+        }
+
+    def __str__(self) -> str:
+        return json.dumps(self.as_dict(), default=str)
