@@ -1,7 +1,6 @@
 from typing import Dict, Any, Optional, Union, List, Callable
 
-# noinspection PyProtectedMember
-from pyspark import keyword_only
+from spark_pipeline_framework.utilities.capture_parameters import capture_parameters
 from pyspark.ml import Transformer
 from pyspark.sql.dataframe import DataFrame
 from spark_pipeline_framework.logger.yarn_logger import get_logger
@@ -13,7 +12,7 @@ from spark_pipeline_framework.transformers.framework_transformer.v1.framework_tr
 
 class FrameworkIfElseTransformer(FrameworkTransformer):
     # noinspection PyUnusedLocal
-    @keyword_only
+    @capture_parameters
     def __init__(
         self,
         enable: Union[bool, Callable[[DataFrame], bool]],
@@ -50,12 +49,18 @@ class FrameworkIfElseTransformer(FrameworkTransformer):
         self.setParams(**kwargs)
 
     def _transform(self, df: DataFrame) -> DataFrame:
+        progress_logger: Optional[ProgressLogger] = self.getProgressLogger()
         enable = self.enable if isinstance(self.enable, bool) else self.enable(df)
         if enable:
             stages: List[Transformer] = (
                 self.stages if isinstance(self.stages, list) else self.stages()
             )
         else:
+            if progress_logger is not None:
+                progress_logger.write_to_log(
+                    self.getName() or "FrameworkIfElseTransformer",
+                    f"Skipping stages because enable {self.enable} did not evaluate to True",
+                )
             stages = (
                 []
                 if self.else_stages is None
@@ -64,7 +69,6 @@ class FrameworkIfElseTransformer(FrameworkTransformer):
                 else self.else_stages()
             )
         for stage in stages:
-            progress_logger: Optional[ProgressLogger] = self.getProgressLogger()
             if progress_logger is not None:
                 progress_logger.start_mlflow_run(run_name=str(stage), is_nested=True)
             if hasattr(stage, "set_loop_id"):
@@ -74,10 +78,14 @@ class FrameworkIfElseTransformer(FrameworkTransformer):
                 progress_logger.end_mlflow_run()
         return df
 
-    def set_loop_id(self, loop_id: str) -> None:
-        """
-        Set when running inside a FrameworkLoopTransformer
-
-        :param loop_id: loop id
-        """
-        self.loop_id = loop_id
+    def as_dict(self) -> Dict[str, Any]:
+        return {
+            **(super().as_dict()),
+            "enable": self.enable,
+            "stages": [s.as_dict() for s in self.stages]
+            if not callable(self.stages)
+            else str(self.stages),
+            "else_stages": [s.as_dict() for s in self.else_stages]
+            if self.else_stages and not callable(self.else_stages)
+            else str(self.else_stages),
+        }
