@@ -1,10 +1,9 @@
 import os
 from glob import glob
 from pathlib import Path
-from typing import Any, Dict, Optional, Union
+from typing import Any, Dict, Optional, Union, cast
 
-# noinspection PyProtectedMember
-from pyspark import keyword_only
+from spark_pipeline_framework.utilities.capture_parameters import capture_parameters
 from pyspark.ml.param import Param
 from pyspark.sql.dataframe import DataFrame
 from spark_pipeline_framework.logger.yarn_logger import get_logger
@@ -20,7 +19,7 @@ from spark_pipeline_framework.utilities.json_to_jsonl_converter import (
 # noinspection SpellCheckingInspection
 class FrameworkJsonToJsonlConverter(FrameworkTransformer):
     # noinspection PyUnusedLocal
-    @keyword_only
+    @capture_parameters
     def __init__(
         self,
         file_path: Union[Path, str],
@@ -92,8 +91,8 @@ class FrameworkJsonToJsonlConverter(FrameworkTransformer):
 
     # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
     def getFilePath(self) -> Union[Path, str]:
-        return self.getOrDefault(self.file_path)
+        return cast(Union[Path, str], self.getOrDefault(self.file_path))
 
     # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
     def getOutputFolder(self) -> Union[Path, str]:
-        return self.getOrDefault(self.output_folder)
+        return cast(Union[Path, str], self.getOrDefault(self.output_folder))
