@@ -76,7 +76,7 @@ class SimplePipeline(FrameworkPipeline):
                 [
                     FrameworkCsvLoader(
                         view="flights",
-                        filepath=parameters["flights_path"],
+                        file_path=parameters["flights_path"],
                         parameters=parameters,
                         progress_logger=progress_logger,
                     ),
