@@ -30,7 +30,7 @@ def test_can_drop_columns(spark_session: SparkSession) -> None:
 
     # Act
     FrameworkCsvLoader(
-        view="my_view", path_to_csv=test_file_path, delimiter=","
+        view="my_view", file_path=test_file_path, delimiter=","
     ).transform(df)
 
     FrameworkSelectColumnsTransformer(
